@@ -361,6 +361,13 @@ class ComputeTask:
 
         self.calc_doc.update(self.cell_dict)
         self.calc_doc.update(self.param_dict)
+
+        # combine source field from all inputs
+        self.calc_doc['source'] = (
+            self.res_dict.get("source", []) +
+            self.cell_dict.get("source", []) +
+            self.param_dict.get("source", [])
+        )
         self.calculator.verify_calculation_parameters(self.calc_doc, self.res_dict)
 
         try:
@@ -394,7 +401,7 @@ class ComputeTask:
             elif self.calc_doc['task'].upper() in ['GEOMETRYOPTIMISATION', 'GEOMETRYOPTIMIZATION']:
                 success = self.run_castep_relaxation()
 
-            elif self.calc_doc['task'].upper() in ['PHONON', 'THERMODYNAMICS']:
+            elif self.calc_doc['task'].upper() in ['PHONON', 'THERMODYNAMICS', 'PHONON+EFIELD']:
                 from matador.workflows.castep import castep_full_phonon
                 success = castep_full_phonon(self, self.calc_doc, self.seed, **self.workflow_kwargs)
 
@@ -402,6 +409,10 @@ class ComputeTask:
                 from matador.workflows.castep import castep_full_spectral
                 success = castep_full_spectral(self, self.calc_doc, self.seed, **self.workflow_kwargs)
 
+            elif self.calc_doc['task'].upper() in ['MAGRES']:
+                from matador.workflows.castep import castep_full_magres
+                success = castep_full_magres(self, self.calc_doc, self.seed, **self.workflow_kwargs)
+
             elif self.calc_doc['task'].upper() in ['BULK_MODULUS']:
                 from matador.workflows.castep import castep_elastic
                 success = castep_elastic(self, self.calc_doc, self.seed, **self.workflow_kwargs)
@@ -694,7 +705,7 @@ class ComputeTask:
         """
         LOG.info('Performing single-shot CASTEP run on {}, with task: {}'.format(seed, calc_doc['task']))
         try:
-            self._singleshot(calc_doc, seed, keep=keep, intermediate=intermediate)
+            return self._singleshot(calc_doc, seed, keep=keep, intermediate=intermediate)
 
         except WalltimeError as err:
             raise err
@@ -784,14 +795,17 @@ class ComputeTask:
             AssertionError: if required key is missing.
 
         """
-        for keyword in forbidden:
-            if keyword in calc_doc:
-                del calc_doc[keyword]
+        if forbidden is not None:
+            for keyword in forbidden:
+                if keyword in calc_doc:
+                    del calc_doc[keyword]
 
         failures = []
-        for keyword in required:
-            if keyword not in calc_doc:
-                failures.append(keyword)
+        if required is not None:
+            for keyword in required:
+                if keyword not in calc_doc:
+                    failures.append(keyword)
+
         if failures:
             raise InputError('The following keywords are required for workflow: {}'.format(', '.join(failures)))
 
@@ -1228,15 +1242,13 @@ class ComputeTask:
         except sp.TimeoutExpired:
             LOG.error("Process reached maximum walltime, cleaning up...")
             self._times_up(process)
+            process.terminate()
             raise WalltimeError("Cleaned up process after reaching maximum walltime")
 
         except Exception as err:
             LOG.error('Unexpected Exception {} caught: terminating job for {}.'.format(type(err).__name__, self.seed))
-            raise err
-
-        finally:
-            LOG.error("Explicitly terminating process.")
             process.terminate()
+            raise err
 
         return out, errs
 
