@@ -10,22 +10,35 @@ inputs and outputs.
 from collections import defaultdict
 import os
 import glob
-import gzip
 import warnings
 import pwd
 import numpy as np
-from matador.utils.cell_utils import abc2cart, calc_mp_spacing, cart2volume, wrap_frac_coords, cart2abc, cart2frac
+from pathlib import Path
+from matador.utils.cell_utils import (
+    abc2cart,
+    calc_mp_spacing,
+    cart2volume,
+    wrap_frac_coords,
+    cart2abc,
+    cart2frac,
+)
 from matador.utils.chem_utils import get_stoich, INVERSE_CM_TO_EV
-from matador.scrapers.utils import DFTError, ComputationError, scraper_function, f90_float_parse
+from matador.scrapers.utils import (
+    DFTError,
+    ComputationError,
+    scraper_function,
+    f90_float_parse,
+    get_flines_extension_agnostic,
+)
 
 
 @scraper_function
-def res2dict(seed, db=True, **kwargs):
+def res2dict(fname, db=True, **kwargs):
     """ Extract available information from .res file; preferably
     used in conjunction with cell or param file.
 
     Parameters:
-        seed (str or list): filename or list of filenames of res file(s)
+        fname (str or list): filename or list of filenames of res file(s)
             (with or without extension).
 
     Keyword arguments:
@@ -36,22 +49,22 @@ def res2dict(seed, db=True, **kwargs):
             if the scrape was successful.
 
     """
+    flines, fname = get_flines_extension_agnostic(fname, "res")
     res = dict()
-    # read .res file into array
-    if seed.endswith('.res'):
-        seed = seed.replace('.res', '')
-    with open(seed + '.res', 'r') as f:
-        flines = f.readlines()
+
     # add .res to source
-    res['source'] = []
-    res['source'].append(seed + '.res')
+    res['source'] = [fname]
     # grab file owner username
     try:
-        res['user'] = pwd.getpwuid(os.stat(seed + '.res').st_uid).pw_name
+        res['user'] = pwd.getpwuid(os.stat(fname).st_uid).pw_name
     except Exception:
         pass
 
-    get_seed_metadata(res, seed)
+    try:
+        get_seed_metadata(res, fname)
+    except Exception as exc:
+        warnings.warn(f'There was an error scraping provenance from filename {fname}: {exc}')
+
     # alias special lines in res file
     titl = ''
     cell = ''
@@ -129,12 +142,12 @@ def res2dict(seed, db=True, **kwargs):
 
 
 @scraper_function
-def cell2dict(seed, db=False, lattice=True, positions=True, **kwargs):
+def cell2dict(fname, db=False, lattice=True, positions=True, **kwargs):
     """ Extract available information from .cell file; probably
     to be merged with another dict from a .param or .res file.
 
     Parameters:
-        seed (str/list): filename or list of filenames of cell file(s)
+        fname (str/list): filename or list of filenames of cell file(s)
             to scrape, with or without extension.
 
     Keyword arguments:
@@ -148,13 +161,11 @@ def cell2dict(seed, db=False, lattice=True, positions=True, **kwargs):
 
     """
     cell = dict()
-    if seed.endswith('.cell'):
-        seed = seed.replace('.cell', '')
-    with open(seed + '.cell', 'r') as f:
-        flines = f.readlines()
+    flines, fname = get_flines_extension_agnostic(fname, "cell")
+
     # add cell file to source
-    cell['source'] = []
-    cell['source'].append(seed + '.cell')
+    cell['source'] = [fname]
+
     for line_no, line in enumerate(flines):
         if line.startswith(('#', '!')):
             continue
@@ -187,6 +198,10 @@ def cell2dict(seed, db=False, lattice=True, positions=True, **kwargs):
             cell['species_pot'] = dict()
             i = 1
             while 'endblock' not in flines[line_no + i].lower():
+                # handle blank lines in species pot
+                if not flines[line_no + i].split():
+                    i += 1
+                    continue
                 if db:
                     species = flines[line_no+i].split()[0]
                     pspot_string = flines[line_no+i].split()[1].split('/')[-1]
@@ -199,6 +214,8 @@ def cell2dict(seed, db=False, lattice=True, positions=True, **kwargs):
                     else:
                         cell['species_pot'][flines[line_no + i].split()[0]] = flines[line_no + i].split()[1]
                 i += 1
+            if not cell['species_pot']:
+                cell.pop('species_pot')
         elif '%block cell_constraints' in line.lower():
             cell['cell_constraints'] = []
             for j in range(2):
@@ -246,6 +263,8 @@ def cell2dict(seed, db=False, lattice=True, positions=True, **kwargs):
         elif 'kpoints_mp_spacing' in line.lower() or 'kpoint_mp_spacing' in line.lower():
             if 'spectral_kpoints_mp_spacing' in line.lower() or 'spectral_kpoint_mp_spacing' in line.lower():
                 cell['spectral_kpoints_mp_spacing'] = f90_float_parse(line.split()[-1])
+            elif 'bs_kpoints_mp_spacing' in line.lower() or 'bs_kpoint_mp_spacing' in line.lower():
+                cell['spectral_kpoints_mp_spacing'] = f90_float_parse(line.split()[-1])
             elif 'supercell_kpoints_mp_spacing' in line.lower() or 'supercell_kpoint_mp_spacing' in line.lower():
                 cell['supercell_kpoints_mp_spacing'] = f90_float_parse(line.split()[-1])
             elif 'phonon_kpoints_mp_spacing' in line.lower() or 'phonon_kpoint_mp_spacing' in line.lower():
@@ -257,6 +276,8 @@ def cell2dict(seed, db=False, lattice=True, positions=True, **kwargs):
         elif 'kpoints_mp_grid' in line.lower() or 'kpoint_mp_grid' in line.lower():
             if 'spectral_kpoints_mp_grid' in line.lower() or 'spectral_kpoint_mp_grid' in line.lower():
                 cell['spectral_kpoints_mp_grid'] = list(map(int, line.split()[-3:]))
+            if 'bs_kpoints_mp_grid' in line.lower() or 'bs_kpoint_mp_grid' in line.lower():
+                cell['spectral_kpoints_mp_grid'] = list(map(int, line.split()[-3:]))
             # these two keywords do not have a corresponding "kpoints" alias (instead of kpoint)
             # so must remain unpluralised (see below for other phonon keyword exceptions)
             elif 'phonon_kpoints_mp_grid' in line.lower() or 'phonon_kpoint_mp_grid' in line.lower():
@@ -268,6 +289,8 @@ def cell2dict(seed, db=False, lattice=True, positions=True, **kwargs):
         elif 'kpoints_mp_offset' in line.lower() or 'kpoint_mp_offset' in line.lower():
             if 'spectral_kpoints_mp_offset' in line.lower() or 'spectral_kpoint_mp_offset' in line.lower():
                 cell['spectral_kpoints_mp_offset'] = list(map(f90_float_parse, line.split()[-3:]))
+            if 'bs_kpoints_mp_offset' in line.lower() or 'bs_kpoint_mp_offset' in line.lower():
+                cell['spectral_kpoints_mp_offset'] = list(map(f90_float_parse, line.split()[-3:]))
             elif 'phonon_kpoints_mp_offset' in line.lower() or 'phonon_kpoint_mp_offset' in line.lower():
                 # this is a special case where phonon_kpointS_mp_offset doesn't exist
                 cell['phonon_kpoint_mp_offset'] = list(map(f90_float_parse, line.split()[-3:]))
@@ -276,31 +299,45 @@ def cell2dict(seed, db=False, lattice=True, positions=True, **kwargs):
             else:
                 cell['kpoints_mp_offset'] = list(map(f90_float_parse, line.split()[-3:]))
         elif '%block' in line.lower() and ('_kpoints_path' in line.lower() or '_kpoint_path' in line.lower()):
-            if 'spectral' in line.lower():
+            if 'spectral_' in line.lower() or "bs_" in line.lower():
                 key = 'spectral_kpoints_path'
-            elif 'phonon_fine' in line.lower():
+            elif 'phonon_fine_' in line.lower():
                 key = 'phonon_fine_kpoint_path'
             else:
-                raise RuntimeError('Found unknown kpoint path block.')
-            i = 1
+                raise RuntimeError(f'Found unknown kpoint path key in line: {line}.')
             labels = []
             found_labels = False
             comment_delims = ['!', '%', '#']
             cell[key] = []
-            while '%endblock' not in flines[line_no + i].lower():
+            for line in flines[line_no+1:]:
+                if "%endblock" in line.lower():
+                    break
+
+                # ignore CASTEP BREAK keyword and let dispersion script figure out discontinuities
+                if "BREAK" in line.strip().upper():
+                    continue
+
+                cell[key].append(list(map(f90_float_parse, line.split()[:3])))
+
                 for delim in comment_delims:
-                    if delim in flines[line_no+i]:
-                        labels.append(flines[line_no+i].split(delim)[-1].strip())
+                    if delim in line:
+                        labels.append(line.split(delim)[-1].strip())
                         found_labels = True
                         break
                 else:
                     labels.append(None)
 
-                cell[key].append(list(map(f90_float_parse, flines[line_no + i].split()[:3])))
-                i += 1
+            else:
+                raise RuntimeError(f"Unable to find closing of block {key}, missing %endblock.")
+
             if found_labels:
                 cell[key + '_labels'] = labels
-        elif '%block spectral_kpoints_list' in line.lower() or '%block spectral_kpoint_list' in line.lower():
+
+        elif any(
+            block in line.lower()
+            for block in
+            ['%block spectral_kpoints_list', '%block spectral_kpoint_list', '%block bs_kpoint_list', '%block bs_kpoints_list']
+        ):
             i = 1
             cell['spectral_kpoints_list'] = []
             while '%endblock' not in flines[line_no + i].lower():
@@ -397,6 +434,8 @@ def cell2dict(seed, db=False, lattice=True, positions=True, **kwargs):
             elif 'kpoints_path' in line.lower() or 'kpoint_path' in line.lower() and '%block' not in line.lower():
                 if 'spectral_kpoints_path_spacing' in line.lower() or 'spectral_kpoint_path_spacing' in line.lower():
                     cell['spectral_kpoints_path_spacing'] = f90_float_parse(line.split()[-1])
+                if 'bs_kpoints_path_spacing' in line.lower() or 'bs_kpoint_path_spacing' in line.lower():
+                    cell['spectral_kpoints_path_spacing'] = f90_float_parse(line.split()[-1])
                 elif 'phonon_fine_kpoints_path_spacing' in line.lower() or 'phonon_fine_kpoint_path_spacing' in line.lower():
                     cell['phonon_fine_kpoint_path_spacing'] = f90_float_parse(line.split()[-1])
                 elif 'kpoints_path_spacing' in line.lower() or 'kpoint_path_spacing' in line.lower():
@@ -421,7 +460,7 @@ def cell2dict(seed, db=False, lattice=True, positions=True, **kwargs):
     if db:
         for species in cell['species_pot']:
             if 'OTF' in cell['species_pot'][species].upper():
-                pspot_seed = '/'.join(seed.split('/')[:-1]) + '/' + cell['species_pot'][species]
+                pspot_seed = '/'.join(fname.split('/')[:-1]) + '/' + cell['species_pot'][species]
                 if os.path.isfile(pspot_seed):
                     cell['species_pot'].update(usp2dict(pspot_seed))
 
@@ -429,12 +468,12 @@ def cell2dict(seed, db=False, lattice=True, positions=True, **kwargs):
 
 
 @scraper_function
-def param2dict(seed, db=True, **kwargs):
+def param2dict(fname, db=True, **kwargs):
     """ Extract available information from .param file; probably
     to be merged with other dicts from other files.
 
     Parameters:
-        seed (str/list): param filename or list of filenames with or
+        fname (str/list): param filename or list of filenames with or
             without file extension
 
     Keyword arguments:
@@ -446,13 +485,9 @@ def param2dict(seed, db=True, **kwargs):
 
     """
     from matador.utils.castep_params import CASTEP_PARAMS
-    param = dict()
-    if seed.endswith('.param'):
-        seed = seed.replace('.param', '')
-    with open(seed + '.param', 'r') as f:
-        flines = f.readlines()
-    param['source'] = []
-    param['source'].append(seed + '.param')
+    flines, fname = get_flines_extension_agnostic(fname, "param")
+    param = {}
+    param['source'] = [fname]
     # exclude some useless info if importing to db
     scrub_list = ['checkpoint', 'write_bib', 'mix_history_length',
                   'fix_occupancy', 'page_wvfns', 'num_dump_cycles',
@@ -549,12 +584,12 @@ def param2dict(seed, db=True, **kwargs):
 
 
 @scraper_function
-def castep2dict(seed, db=True, intermediates=False, **kwargs):
+def castep2dict(fname, db=True, intermediates=False, **kwargs):
     """ From seed filename, create dict of the most relevant
     information about a calculation.
 
     Parameters:
-        seed (str/list): filename or list of filenames of castep file(s)
+        fname (str/list): filename or list of filenames of castep file(s)
 
     Keyword arguments:
         db (bool): whether to error on missing relaxation info
@@ -566,39 +601,23 @@ def castep2dict(seed, db=True, intermediates=False, **kwargs):
             if the scrape was successful.
 
     """
-    if seed.endswith('.history'):
-        seed = seed.replace('.history', '')
-        ftype = 'history'
-    elif seed.endswith('.history.gz'):
-        seed = seed.replace('.history.gz', '')
-        ftype = 'history.gz'
-    else:
-        seed = seed.replace('.castep', '')
-        ftype = 'castep'
-
-    seed = '{}.{}'.format(seed, ftype)
+    flines, fname = get_flines_extension_agnostic(fname, ["castep", "history", "history.gz"])
 
     castep = dict()
-    # read .castep, .history or .history.gz file
-    if ftype == 'history.gz':
-        with gzip.open(seed, 'r') as f:
-            flines = [line.decode('utf-8') for line in f.readlines()]
-    else:
-        try:
-            with open(seed, 'r', encoding='utf-8') as f:
-                flines = f.readlines()
-        except Exception:
-            with open(seed, 'r', encoding='latin1') as f:
-                flines = f.readlines()
     # set source tag to castep file
-    castep['source'] = []
-    castep['source'].append(seed)
+    castep['source'] = [fname]
+
     # grab file owner
     try:
-        castep['user'] = pwd.getpwuid(os.stat(seed).st_uid).pw_name
+        castep['user'] = pwd.getpwuid(os.stat(fname).st_uid).pw_name
     except Exception:
         pass
-    get_seed_metadata(castep, seed.replace('.' + ftype, ''))
+
+    try:
+        get_seed_metadata(castep, fname)
+    except Exception as exc:
+        warnings.warn(f'There was an error scraping provenance from filename {fname}: {exc}')
+
     # wrangle castep file for parameters in 3 passes:
     # once forwards to get number and types of atoms
     _castep_scrape_atoms(flines, castep)
@@ -646,11 +665,7 @@ def castep2dict(seed, db=True, intermediates=False, **kwargs):
     if db:
         for species in castep['species_pot']:
             if 'OTF' in castep['species_pot'][species].upper():
-                pspot_seed = ''
-                for directory in seed.split('/')[:-1]:
-                    pspot_seed += directory + '/'
-                # glob for all .usp files with format species_*OTF.usp
-                pspot_seed += castep['species_pot'][species]
+                pspot_seed = str(Path(fname).parent.joinpath(castep['species_pot'][species]))
                 for globbed in glob.glob(pspot_seed):
                     if os.path.isfile(globbed):
                         castep['species_pot'].update(usp2dict(globbed))
@@ -666,12 +681,12 @@ def castep2dict(seed, db=True, intermediates=False, **kwargs):
 
 
 @scraper_function
-def bands2dict(seed, **kwargs):
+def bands2dict(fname, **kwargs):
     """ Parse a CASTEP bands file into a dictionary, which can be used as input to
     an :obj:`matador.orm.spectral.ElectronicDispersion` object.
 
     Parameters:
-        seed (str/list): filename of list of filenames to be scraped.
+        fname (str/list): filename of list of filenames to be scraped.
 
     Returns:
         (tuple): containing either dict/str containing data or error, and a bool stating
@@ -681,13 +696,12 @@ def bands2dict(seed, **kwargs):
     from matador.utils.chem_utils import HARTREE_TO_EV, BOHR_TO_ANGSTROM
 
     bs = dict()
-    with open(seed, 'r') as f:
-        # read whole file into RAM, typically ~ 1 MB
-        flines = f.readlines()
+    flines, fname = get_flines_extension_agnostic(fname, "bands")
+
     header = flines[:9]
     data = flines[9:]
 
-    bs['source'] = [seed]
+    bs['source'] = [fname]
 
     bs['num_kpoints'] = int(header[0].split()[-1])
     bs['num_spins'] = int(header[1].split()[-1])
@@ -724,24 +738,26 @@ def bands2dict(seed, **kwargs):
 
 
 @scraper_function
-def arbitrary2dict(seed, **kwargs):
+def arbitrary2dict(fname, **kwargs):
     """ Read arbitrary CASTEP-style input files into
     a dictionary.
 
     Parameters:
-        seed (str/list): filename or list of filenames.
+        fname (str/list): filename or list of filenames.
 
     Returns:
         (tuple): containing either dict/str containing data or error, and a bool stating
             if the scrape was successful.
 
     """
-    with open(seed, 'r') as f:
-        flines = f.readlines()
+
+    flines, fname = get_flines_extension_agnostic(fname, None)
+
     splitters = [':', '=', '\t', ' ']
     comment_delims = ['!', '%', '#', '/*', '*/']
+
     result = {}
-    result['source'] = [seed]
+    result['source'] = [fname]
     for line in flines:
         comment = False
         for delim in comment_delims:
@@ -760,12 +776,12 @@ def arbitrary2dict(seed, **kwargs):
 
 
 @scraper_function
-def optados2dict(seed, **kwargs):
+def optados2dict(fname, **kwargs):
     """ Scrape optados output file (*.*.dat) or (*.pdos.*.dat)
     for DOS, projectors and projected DOS/dispersion.
 
     Parameters:
-        seed (str/list): optados filename or list of filenames.
+        fname (str/list): optados filename or list of filenames.
 
     Returns:
         (tuple): containing either dict/str containing data or error, and a bool stating
@@ -777,8 +793,8 @@ def optados2dict(seed, **kwargs):
     is_pdis = False
     is_spin_dos = False
     dos_unit_label = None
-    with open(seed, 'r') as f:
-        flines = f.readlines()
+
+    flines, fname = get_flines_extension_agnostic(fname, None)
 
     header = []
     header_ind = 0
@@ -800,7 +816,7 @@ def optados2dict(seed, **kwargs):
     flines = flines[header_ind:]
 
     if not is_pdis:
-        data = np.loadtxt(seed, comments='#')
+        data = np.loadtxt(fname, comments='#')
         optados['energies'] = data[:, 0]
 
     if is_pdos or is_pdis:
@@ -863,11 +879,11 @@ def optados2dict(seed, **kwargs):
 
 
 @scraper_function
-def phonon2dict(seed, **kwargs):
+def phonon2dict(fname, **kwargs):
     """ Parse a CASTEP phonon file into a dictionary.
 
     Parameters:
-        seed (str/list): phonon filename or list of filenames.
+        fname (str/list): phonon filename or list of filenames.
 
     Returns:
         (tuple): containing either dict/str containing data or error, and a bool stating
@@ -875,18 +891,10 @@ def phonon2dict(seed, **kwargs):
 
     """
 
-    with open(seed, 'r') as f:
-        # read whole file into RAM, typically <~ 1 MB
-        flines = f.readlines()
+    flines, fname = get_flines_extension_agnostic(fname, ["phonon", "phonon_dos"])
 
     ph = dict()
-
-    if 'phonon_dos' in seed:
-        seed = seed.replace('.phonon_dos', '')
-        ph['source'] = [seed + '.phonon_dos']
-    else:
-        seed = seed.replace('.phonon', '')
-        ph['source'] = [seed + '.phonon']
+    ph['source'] = [fname]
 
     dos_present = False
     data_start = 0
@@ -906,6 +914,7 @@ def phonon2dict(seed, **kwargs):
             ph['lattice_cart'] = []
             for i in range(3):
                 ph['lattice_cart'].append([f90_float_parse(elem) for elem in flines[line_no + i + 1].split()])
+            ph['lattice_abc'] = cart2abc(ph['lattice_cart'])
         elif 'fractional co-ordinates' in line:
             ph['positions_frac'] = []
             ph['atom_types'] = []
@@ -921,7 +930,7 @@ def phonon2dict(seed, **kwargs):
         elif 'begin dos' in line:
             dos_present = True
             projector_labels = flines[line_no].split()[5:]
-            projector_labels = [(label, None) for label in projector_labels]
+            projector_labels = [(label, None, None) for label in projector_labels]
             begin_dos = line_no + 1
 
         elif 'q-pt' in line:
@@ -969,9 +978,13 @@ def phonon2dict(seed, **kwargs):
         ph['energies'] = raw_data[:, 0] * INVERSE_CM_TO_EV
         ph['dos'] = raw_data[:, 1]
         ph['pdos'] = dict()
+        ph['pdos']['pdos'] = dict()
+        ph['pdos']["projectors"] = []
+        ph['pdos']["energies"] = ph["energies"]
 
         for i, label in enumerate(projector_labels):
-            ph['pdos'][label] = raw_data[:, i + 2]
+            ph['pdos']['pdos'][label] = raw_data[:, i + 2]
+            ph['pdos']["projectors"].append(label)
 
     ph['kpoint_path'] = np.asarray([qpt[0:3] for qpt in ph['phonon_kpoint_list']])
     ph['kpoint_weights'] = [qpt[3] for qpt in ph['phonon_kpoint_list']]
@@ -993,19 +1006,19 @@ def phonon_dos2dict(*args, **kwargs):
     return phonon2dict(*args, no_wrap=True, **kwargs)
 
 
-def usp2dict(seed, **kwargs):
+def usp2dict(fname, **kwargs):
     """ Extract pseudopotential string from a CASTEP
     OTF .USP file.
 
     Parameters:
-        seed (str/list): filename of usp file, or list of filenames.
+        fname (str/list): filename of usp file, or list of filenames.
 
     Returns:
         dict: partial species_pot dict from usp file.
 
     """
     species_pot = dict()
-    with open(seed, 'r') as f:
+    with open(fname, 'r') as f:
         flines = f.readlines()
         for line_no, line in enumerate(flines):
             if 'Pseudopotential Report' in line:
@@ -1892,19 +1905,47 @@ def get_seed_metadata(doc, seed):
         seed (str): the filename that is being scraped (sans file extension).
 
     """
+    errors = []
     if '-CollCode-' in seed:
-        doc['icsd'] = int(seed.split('CollCode-')[-1].split('-')[0].split('_')[0].split('.')[0])
+        try:
+            doc['icsd'] = int(seed.split('CollCode-')[-1].split('-')[0].split('_')[0].split('.')[0])
+        except ValueError as exc:
+            errors.append(exc)
     elif 'CollCode' in seed:
-        doc['icsd'] = int(seed.split('CollCode')[-1].split('-')[0].split('_')[0].split('.')[0])
+        try:
+            doc['icsd'] = int(seed.split('CollCode')[-1].split('-')[0].split('_')[0].split('.')[0])
+        except ValueError as exc:
+            errors.append(exc)
     elif '-ICSD-' in seed:
-        doc['icsd'] = int(seed.split('-ICSD-')[-1].split('-')[0].split('_')[0].split('.')[0])
+        try:
+            doc['icsd'] = int(seed.split('-ICSD-')[-1].split('-')[0].split('_')[0].split('.')[0])
+        except ValueError as exc:
+            errors.append(exc)
     if '-OQMD-' in seed:
-        doc['oqmd_id'] = int(seed.split('-OQMD-')[-1].split('-')[0].split('_')[0].split('.')[0])
+        try:
+            doc['oqmd_id'] = int(seed.split('-OQMD-')[-1].split('-')[0].split('_')[0].split('.')[0])
+        except ValueError as exc:
+            errors.append(exc)
     elif '-OQMD_' in seed:
-        doc['oqmd_id'] = int(seed.split('-OQMD_')[-1].split('-')[0].split('_')[0].split('.')[0])
+        try:
+            doc['oqmd_id'] = int(seed.split('-OQMD_')[-1].split('-')[0].split('_')[0].split('.')[0])
+        except ValueError as exc:
+            errors.append(exc)
     if '-MP-' in seed:
-        doc['mp_id'] = int(seed.split('-MP-')[-1].split('-')[0].split('_')[0].split('.')[0])
+        try:
+            doc['mp_id'] = int(seed.split('-MP-')[-1].split('-')[0].split('_')[0].split('.')[0])
+        except ValueError as exc:
+            errors.append(exc)
     elif '-MP_' in seed:
-        doc['mp_id'] = int(seed.split('-MP_')[-1].split('-')[0].split('_')[0].split('.')[0])
+        try:
+            doc['mp_id'] = int(seed.split('-MP_')[-1].split('-')[0].split('_')[0].split('.')[0])
+        except ValueError as exc:
+            errors.append(exc)
     if '-DOI-' in seed:
-        doc['doi'] = seed.split('-DOI-')[-1].split('-')[0].replace('__', '/')
+        try:
+            doc['doi'] = seed.split('-DOI-')[-1].split('-')[0].replace('__', '/')
+        except ValueError as exc:
+            errors.append(exc)
+
+    if errors:
+        raise ValueError(errors)
