@@ -121,7 +121,7 @@ class SpectralPlotTests(unittest.TestCase):
         sys.argv = [
             "dispersion",
             "KPSn",
-            "KPSn_2.bands",
+            "KPSn_2",
             "--dos_only",
             "--cmap",
             "viridis",
@@ -132,6 +132,9 @@ class SpectralPlotTests(unittest.TestCase):
             "--figsize",
             "10",
             "10",
+            "--colours",
+            "green",
+            "red"
         ]
         errored = False
         try:
@@ -181,8 +184,10 @@ class SpectralPlotTests(unittest.TestCase):
             "K3P",
             "--png",
             "-ph",
-            "--band_colour",
-            "k",
+            "--colours",
+            "grey",
+            "green",
+            "blue",
             "--figsize",
             "10",
             "10",
@@ -404,7 +409,7 @@ class MagresPlotTests(MatadorUnitTest):
     """ Test ability to plot magres data. """
 
     def test_magres_plot(self):
-        magres, f = magres2dict(REAL_PATH + "data/magres_files/*.magres", as_model=True)
+        magres, f = magres2dict(REAL_PATH + "data/magres_files/*P*.magres", as_model=True)
         plot_magres(
             magres,
             species="P",
@@ -415,9 +420,9 @@ class MagresPlotTests(MatadorUnitTest):
         plot_magres(
             magres,
             species="Li",
-            magres_key="chemical_shielding_aniso",
+            broadening_width=0,
+            magres_key="chemical_shift_aniso",
             savefig="magres_Li.png",
-            xlabel="Chemical shielding anisotropy",
             signal_labels=["NaP", "LiP"],
             line_kwargs=[{"lw": 3}, {"ls": "--"}],
         )
