@@ -12,7 +12,7 @@ import numpy as np
 
 from .utils import MatadorUnitTest, REAL_PATH, detect_program
 from matador.compute import ComputeTask
-from matador.scrapers import cell2dict, param2dict, phonon2dict
+from matador.scrapers import cell2dict, param2dict, phonon2dict, magres2dict
 
 
 HOSTNAME = os.uname()[1]
@@ -32,7 +32,7 @@ else:
 
 @unittest.skipIf(not CASTEP_PRESENT, "CASTEP not found.")
 class ElasticWorkflowTest(MatadorUnitTest):
-    """ Run a spectral workflow calculation. """
+    """ Run a elastic workflow calculation. """
 
     def test_bulk_mod(self):
         for _f in glob.glob(REAL_PATH + "data/elastic_workflow/*"):
@@ -49,16 +49,29 @@ class ElasticWorkflowTest(MatadorUnitTest):
             param_dict=param_dict,
             verbosity=VERBOSITY,
             compute_dir="/tmp/scratch_test",
-            workflow_kwargs={"plot": False, "num_volumes": 3},
+            workflow_kwargs={"plot": False, "num_volumes": 5},
         )
 
         self.assertFalse(os.path.isfile("completed/Si2.bib"))
-        self.assertFalse(os.path.isfile("completed/Si2.check"))
+        self.assertTrue(os.path.isfile("completed/Si2.check"))
 
         self.assertTrue(os.path.isfile("completed/Si2.bulk_mod.results"))
         self.assertTrue(os.path.isfile("completed/Si2.bulk_mod.res"))
         self.assertTrue(os.path.isfile("completed/Si2.bulk_mod.castep"))
-        self.assertFalse(os.path.isfile("completed/Si2.bulk_mod.png"))
+
+        with open("completed/Si2.bulk_mod.results", "r") as f:
+            flines = f.readlines()
+
+        B = []
+        for line in flines:
+            if "bulk modulus" in line:
+                B.append(float(line.split()[3]))
+
+        # check all computed bulk mods are between 88-92
+        self.assertEqual(len(B), 3)
+        self.assertTrue(all(abs(b - 90) < 2) for b in B)
+
+        self.assertFalse(os.path.isfile("completed/Si2.bulk_mod.pdf"))
 
         self.assertTrue(os.path.isfile("completed/Si2.res"))
         self.assertTrue(os.path.isfile("completed/Si2.geom"))
@@ -71,7 +84,7 @@ class ElasticWorkflowTest(MatadorUnitTest):
 
 @unittest.skipIf(not CASTEP_PRESENT, "CASTEP not found.")
 class PhononWorkflowTest(MatadorUnitTest):
-    """ Run a spectral workflow calculation. """
+    """ Run a phonon workflow calculation. """
 
     def test_phonon(self):
         for _f in glob.glob(REAL_PATH + "data/phonon_workflow/*"):
@@ -99,6 +112,15 @@ class PhononWorkflowTest(MatadorUnitTest):
         self.assertTrue(os.path.isfile("completed/Si2.phonon_dos"))
 
         phon, s = phonon2dict("completed/Si2.phonon")
+        a = 2.7355124
+        np.testing.assert_array_almost_equal(
+            phon["lattice_cart"], np.array([[0, a, a], [a, 0, a], [a, a, 0]]), decimal=3
+        )
+
+        a = 3.869
+        np.testing.assert_array_almost_equal(
+            phon["lattice_abc"], np.array([[a, a, a], [60, 60, 60]]), decimal=3
+        )
         self.assertTrue(s, msg="Failed to read phonon file")
         self.assertGreater(np.min(phon["eigenvalues_q"]), -0.05)
 
@@ -106,6 +128,64 @@ class PhononWorkflowTest(MatadorUnitTest):
         self.assertTrue(os.path.isfile("completed/Si2.res"))
 
 
+@unittest.skipIf(not CASTEP_PRESENT, "CASTEP not found.")
+class MagresWorkflowTest(MatadorUnitTest):
+    """ Run a magres workflow calculation. """
+
+    def test_magres(self):
+        for _f in glob.glob(REAL_PATH + "data/magres_workflow/*"):
+            shutil.copy(_f, ".")
+
+        cell_dict, _ = cell2dict("Si.cell", db=False)
+        param_dict, _ = param2dict("Si.param", db=False)
+        _ = ComputeTask(
+            res="Si2.res",
+            ncores=NCORES,
+            nnodes=None,
+            node=None,
+            cell_dict=cell_dict,
+            param_dict=param_dict,
+            verbosity=VERBOSITY,
+            compute_dir="tmpier_tst",
+            workflow_kwargs={"final_elec_energy_tol": 1e-9},
+        )
+
+        self.assertTrue(os.path.isfile("completed/Si2.check"))
+
+        self.assertTrue(os.path.isfile("completed/Si2.bands"))
+        self.assertTrue(os.path.isfile("completed/Si2.castep"))
+        self.assertTrue(os.path.isfile("completed/Si2.magres"))
+
+        self.assertTrue(os.path.isfile("completed/Si2.cell_magres"))
+        self.assertTrue(os.path.isfile("completed/Si2.param_magres"))
+
+        self.assertTrue(os.path.isfile("completed/Si2.cell_scf"))
+        self.assertTrue(os.path.isfile("completed/Si2.param_scf"))
+
+        param, s = param2dict("completed/Si2.param_scf")
+        self.assertTrue(s, msg="Failed to read param file")
+        self.assertEqual(param["elec_energy_tol"], 1e-12)
+
+        param, s = param2dict("completed/Si2.param_magres")
+        self.assertEqual(param["elec_energy_tol"], 1e-12)
+        self.assertTrue(s, msg="Failed to read param file")
+
+        magres, s = magres2dict("completed/Si2.magres")
+        self.assertTrue(s, msg="Failed to read magres file")
+
+        a = 3.866895
+        np.testing.assert_array_almost_equal(
+            magres["lattice_abc"], np.array([[a, a, a], [60, 60, 60]]), decimal=3
+        )
+
+        np.testing.assert_array_almost_equal(
+            magres["chemical_shielding_isos"], np.array([129.577, 129.577]), decimal=2
+        )
+
+        self.assertTrue(os.path.isfile("completed/Si2.cell"))
+        self.assertTrue(os.path.isfile("completed/Si2.res"))
+
+
 @unittest.skipIf(not CASTEP_PRESENT, "CASTEP not found.")
 class SpectralWorkflowTest(MatadorUnitTest):
     """ Run a spectral workflow calculation. """
